# The _ssos_ Pipeline
---
[![Documentation Status](https://readthedocs.org/projects/sso-pipeline/badge/?version=latest)](https://sso-pipeline.readthedocs.io/en/latest/?badge=latest)

Pipeline to identify and recover astrometry and photometry of Solar System Objects in imaging surveys.

Online documentation at https://sso-pipeline.readthedocs.io/en/latest/
